# Sources
- `Calc_3d.py`
- `Calc_diff_ops.py`
- `Taylor.py`

# Required pacakges
- numpy: `conda intall numpy`
- scipy: `conda install scipy`
- cm2utils: `[your anaconda env]/bin/pip install cm2utils`, developed by CM2Lab.